.. -*- coding: utf-8 -*-

.. _vector_calculus:

=============================================
Tutorial: Vector Calculus in Euclidean Spaces
=============================================

.. MODULEAUTHOR:: Eric Gourgoulhon

This document contains various tutorials introducing vector calculus with
SageMath. The first one regards vector calculus in the 3-dimensional
Euclidean space :math:`\mathbb{E}^3` in Cartesian coordinates, focusing on the
evaluation of the standard vector operators. The second tutorial deals with the
same topic but based on curvilinear (spherical and cylindrical) coordinates.
The third tutorial is devoted to changes between the various coordinate systems.
The fourth tutorial presents some advanced aspects, namely the treatment of
:math:`\mathbb{E}^3` as a Riemannian manifold. Finally, the last tutorial is
devoted to 2-dimensional vector calculus, using both Cartesian and polar
coordinates in the Euclidean plane :math:`\mathbb{E}^2`; it combines various
features of the other tutorials.

.. toctree::
   :maxdepth: 1

   vector_calculus/vector_calc_cartesian
   vector_calculus/vector_calc_curvilinear
   vector_calculus/vector_calc_change
   vector_calculus/vector_calc_advanced
   vector_calculus/vector_calc_plane
